@@ -1,6 +1,6 @@
 #![doc = include_str!("../README.md")]
 
-pub mod bindgen {
+mod bindgen {
     #![allow(non_upper_case_globals)]
     #![allow(non_camel_case_types)]
     #![allow(non_snake_case)]
@@ -10,14 +10,15 @@ pub mod bindgen {
 pub mod bindings;
 pub mod bitmap;
 pub mod bitmap_config;
+pub mod color;
 pub mod document;
+pub mod error;
+pub mod form;
+pub mod metadata;
 pub mod page;
+pub mod pages;
 pub mod pdfium;
-
-use crate::bindgen::{
-    FPDF_ERR_FILE, FPDF_ERR_FORMAT, FPDF_ERR_PAGE, FPDF_ERR_PASSWORD, FPDF_ERR_SECURITY,
-    FPDF_ERR_UNKNOWN,
-};
+mod utils;
 
 // Conditional compilation is used to compile different implementations of
 // the PdfiumLibraryBindings trait depending on whether we are compiling to a
@@ -29,29 +30,6 @@ mod native;
 #[cfg(target_arch = "wasm32")]
 mod wasm;
 
-pub type PdfPageIndex = u16;
-pub type PdfPoints = f32;
-
-#[derive(Debug)]
-pub enum PdfiumInternalError {
-    Unknown = FPDF_ERR_UNKNOWN as isize,
-    FileError = FPDF_ERR_FILE as isize,
-    FormatError = FPDF_ERR_FORMAT as isize,
-    PasswordError = FPDF_ERR_PASSWORD as isize,
-    SecurityError = FPDF_ERR_SECURITY as isize,
-    PageError = FPDF_ERR_PAGE as isize,
-}
-
-#[derive(Debug)]
-pub enum PdfiumError {
-    DynamicLibraryLoadingNotSupportedOnWASM,
-    #[cfg(not(target_arch = "wasm32"))]
-    LoadLibraryError(libloading::Error),
-    PageIndexOutOfBounds,
-    UnknownBitmapFormat,
-    PdfiumLibraryInternalError(PdfiumInternalError),
-}
-
 #[cfg(test)]
 pub mod tests {
     use crate::bitmap::PdfBitmapRotation;
@@ -69,12 +47,15 @@ pub mod tests {
         let render_config = PdfBitmapConfig::new()
             .set_target_width(2000)
             .set_maximum_height(2000)
-            .rotate_if_landscape(PdfBitmapRotation::Degrees90, true);
+            .rotate_if_landscape(PdfBitmapRotation::Degrees90, true)
+            .render_form_data(true)
+            .render_annotations(true);
 
         Pdfium::new(bindings.unwrap())
-            .load_pdf_from_file("./test/test.pdf", None)
+            .load_pdf_from_file("./test/form-test.pdf", None)
             .unwrap()
             .pages()
+            .iter()
             .for_each(|page| {
                 let result = page
                     .get_bitmap_with_config(&render_config)
@@ -82,7 +63,10 @@ pub mod tests {
                     .as_image()
                     .as_bgra8()
                     .unwrap()
-                    .save_with_format(format!("test-page-{}.jpg", page.index()), ImageFormat::Jpeg);
+                    .save_with_format(
+                        format!("form-test-page-{}.jpg", page.index()),
+                        ImageFormat::Jpeg,
+                    );
 
                 assert!(result.is_ok());
             });
